@@ -9,7 +9,11 @@ from __future__ import print_function
 from fast_tracker.admin import command, usage
 
 
-@command("run-program", "...", """执行命令行来启动应用,但它会强制初始化代理. 环境变量FastTrackerConfigPath可以提供代理配置文件的路径,日志文件的详情由FAST_LOG提供""")
+@command(
+    "run-program",
+    "...",
+    """执行命令行来启动应用,但它会强制初始化代理. 环境变量FastTrackerConfigPath可以提供代理配置文件的路径,日志文件的详情由FAST_LOG提供""",
+)
 def run_program(args):
     import os
     import sys
@@ -19,18 +23,21 @@ def run_program(args):
         usage("run-program")
         sys.exit(1)
 
-    startup_debug = os.environ.get("FastTracker.Debug", "off").lower() in ("on", "true", "1")
-    fast_debug_level = int(os.environ.get("FastTracker.Debug.Level", "0"))
+    startup_debug = os.environ.get("FastTracker_Debug", "off").lower() in (
+        "on",
+        "true",
+        "1",
+    )
+
+    fast_debug_level = int(os.environ.get("FastTracker_Debug_Level", "0"))
 
     def log_message(text, *args, level=1):
-        if startup_debug:
-            if fast_debug_level >= level:
-                text = text % args
-                timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-                sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(), text))
-                sys.stdout.flush()
+        if startup_debug and fast_debug_level >= level:
+            text = text % args
+            timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+            print("FAST: %s (%d) - %s" % (timestamp, os.getpid(), text))
 
-    log_message("FAST Admin Script (%s)", __file__)
+    log_message("FAST Boot Script (%s)", __file__)
 
     log_message("working_directory = %r", os.getcwd())
     log_message("current_command = %r", sys.argv)
@@ -64,7 +71,11 @@ def run_program(args):
     if "PYTHONPATH" in os.environ:
         path = os.environ["PYTHONPATH"].split(os.path.pathsep)
         if boot_directory not in path:
-            python_path = "%s%s%s" % (boot_directory, os.path.pathsep, os.environ["PYTHONPATH"])
+            python_path = "%s%s%s" % (
+                boot_directory,
+                os.path.pathsep,
+                os.environ["PYTHONPATH"],
+            )
 
     os.environ["PYTHONPATH"] = python_path
 
@@ -88,4 +99,3 @@ def run_program(args):
     log_message("execl_arguments = %r", [program_exe_path] + args)
 
     os.execl(program_exe_path, *args)
-
