@@ -39,7 +39,7 @@ def install():
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
         if "gunicorn" in err_log or "kafka" in err_log or "tornado" in err_log or "werkzeug" in err_log:
-            res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
+            res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info, stacklevel=stacklevel)
 
             return res
 
@@ -52,21 +52,21 @@ def install():
                 data = params_tostring(msg, level)
                 span.logs.append(Log(items=[LogItem(key=ComponentType.Log, val=data)]))
 
-                res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
+                res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info, stacklevel=stacklevel)
 
                 return res
         else:
             # 当配置文件中的配置的日记级别高于当前上报日志级别，则不做探针上报，也就是说拦截器什么都不做，只负责调用日志原始处理器
-            res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
+            res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info, stacklevel=stacklevel)
 
             return res
 
-    def _fast_py35_handle(this: logging.Logger, level, msg, args, exc_info=None, extra=None):
+    def _fast_py35_handle(this: logging.Logger, level, msg, args, exc_info=None, extra=None, stack_info=None):
         # 当gunicorn模式启动时，gunicorn会自行上报log信息，也会被此插件拦截，故需剔除gunicorn的log上报 eg：<Logger gunicorn.error (INFO)>
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
         if "gunicorn" in err_log or "kafka" in err_log or "tornado" in err_log or "werkzeug" in err_log:
-            res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
+            res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info)
 
             return res
 
@@ -79,12 +79,12 @@ def install():
                 data = params_tostring(msg, level)
                 span.logs.append(Log(items=[LogItem(key=ComponentType.Log, val=data)]))
 
-                res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
+                res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info)
 
                 return res
         else:
             # 当配置文件中的配置的日记级别高于当前上报日志级别，则不做探针上报，也就是说拦截器什么都不做，只负责调用日志原始处理器
-            res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
+            res = _handle(this, level, msg, args, exc_info=exc_info, extra=extra, stack_info=stack_info)
 
             return res
 
