@@ -19,23 +19,23 @@ def install():
     _request = Session.request
 
     def _fast_request(
-            this: Session,
-            method,
-            url,
-            params=None,
-            data=None,
-            headers=None,
-            cookies=None,
-            files=None,
-            auth=None,
-            timeout=None,
-            allow_redirects=True,
-            proxies=None,
-            hooks=None,
-            stream=None,
-            verify=None,
-            cert=None,
-            json=None,
+        this: Session,
+        method,
+        url,
+        params=None,
+        data=None,
+        headers=None,
+        cookies=None,
+        files=None,
+        auth=None,
+        timeout=None,
+        allow_redirects=True,
+        proxies=None,
+        hooks=None,
+        stream=None,
+        verify=None,
+        cert=None,
+        json=None,
     ):
 
         from urllib.parse import urlparse
@@ -65,20 +65,25 @@ def install():
             )
 
         context = get_context()
-        # functions.log("request url:%s", url_param.path)
-        with context.new_exit_span(op=url_param.path.split("?")[0] or "/", peer=url_param.netloc) as span:
+        trace_id_name = config.get_trace_id_name()
+        trace_id = ""
+        with context.new_exit_span(op=url_param.path or "/", peer=url_param.netloc) as span:
             carrier = span.inject()
-            functions.log("frq carrier val:%s",carrier.val)
             span.layer = Layer.Http
             span.component = ComponentType.Requests
 
             if headers is None:
                 headers = {}
             for item in carrier:
+                if getattr(item, "trace_id", None):
+                    trace_id = item.trace_id
                 headers[item.key] = item.val
 
+            headers[trace_id_name] = trace_id
+
             span.tag(Tag(key=tags.HttpMethod, val=method.upper()))
             span.tag(Tag(key=tags.HttpUrl, val=url))
+            span.tag(Tag(key=tags.HttpHeaders, val=headers))
             # HttpPath 只需要获取PATH_INFO信息即可，不需要？后的内容
             span.tag(Tag(key=tags.HttpPath, val=url_param.path))
 
@@ -106,6 +111,8 @@ def install():
             if res.status_code >= 400:
                 span.error_occurred = True
 
+            functions.log("requests span is: %r", span)
+
             return res
 
     Session.request = _fast_request
