@@ -9,7 +9,7 @@ from typing import List
 
 from fast_tracker import config
 from fast_tracker.utils.lang import b64encode, b64decode
-from fast_tracker.utils import functions
+
 
 class CarrierItem(object):
     def __init__(self, key: str = "", val: str = ""):
@@ -37,7 +37,6 @@ class Carrier(CarrierItem):
     def __init__(
         self,
         trace_id: str = "",
-        parent_id: str = "",
         segment_id: str = "",
         span_id: str = "",
         service: str = "",
@@ -58,25 +57,22 @@ class Carrier(CarrierItem):
         self.correlation_carrier = FastCorrelationCarrier()
         self.items = [self.correlation_carrier, self]  # type: List[CarrierItem]
         self.__iter_index = 0  # type: int
-        self.parent_id = parent_id
         if correlation is not None:
             self.correlation_carrier.correlation = correlation
 
     @property
     def val(self) -> str:
-        fast_tracker = "-".join(
+        return "-".join(
             [
                 b64encode(self.trace_id),
-                b64encode(self.span_id),
-                b64encode(self.segment_id),
-                b64encode(self.service),
-                b64encode(self.service_instance),
-                b64encode(self.endpoint),
-                b64encode(self.client_address),
+                self.span_id,
+                # b64encode(self.segment_id),
+                # b64encode(self.service),
+                # b64encode(self.service_instance),
+                # b64encode(self.endpoint),
+                # b64encode(self.client_address),
             ]
         )
-        functions.log("fast_tracker:%s",fast_tracker)
-        return fast_tracker
 
     @val.setter
     def val(self, val: str):
@@ -87,7 +83,7 @@ class Carrier(CarrierItem):
         if len(parts) != 7:
             return
         self.trace_id = b64decode(parts[0])
-        self.span_id = b64decode(parts[1])
+        self.span_id = parts[1]
         self.segment_id = b64decode(parts[2])
         self.service = b64decode(parts[3])
         self.service_instance = b64decode(parts[4])
@@ -97,9 +93,6 @@ class Carrier(CarrierItem):
     def set_frontend_trace_id(self, trace_id):
         self.trace_id = trace_id
 
-    def set_parent_id(self,parent_id):
-        self.parent_id = parent_id
-
     @property
     def is_valid(self):
         # type: () -> bool
